@@ -131,7 +131,7 @@ func TestDoCommandMultipleReturnValues(t *testing.T) {
 		t.Fatal(err)
 	}
 	if person.Name != "Ms. Jennifer" {
-		t.Errorf("Invalid name. Expected 'Mr. Johson' and got '%s'", person.Name)
+		t.Errorf("Invalid name. Expected 'Mr. Jennifer' and got '%s'", person.Name)
 	}
 	if person.Age != 28 {
 		t.Errorf("Invalid age. Expected '28' and got '%d'", person.Age)
@@ -610,6 +610,7 @@ func TestClear(t *testing.T) {
 
 	connection.Do("HGETALL", "person:1")
 	connection.Do("HGETALL", "person:2")
+	connection.Do("HGET", "non-existent-key")
 
 	connection.Clear()
 
@@ -624,6 +625,10 @@ func TestClear(t *testing.T) {
 	if len(connection.stats) > 0 {
 		t.Error("Clear function not clearing stats")
 	}
+
+	if len(connection.errors) > 0 {
+		t.Error("Clear function not clearing errors")
+	}
 }
 
 func TestStats(t *testing.T) {
